LensKit for Java
================

This page documents usage of the deprecated Java version of LensKit.  Documentation for
that version can be found at https://java.lenskit.org.

Citation
~~~~~~~~

If you publish research that uses the old Java version of LensKit, cite:

.. raw:: html

    <div class="citation" markdown="span">
    Michael D. Ekstrand, Michael Ludwig, Joseph A. Konstan,
    and John T. Riedl. 2011. <a href="http://md.ekstrandom.net/research/pubs/lenskit"
    class="pub-title">Rethinking The Recommender Research Ecosystem:
    Reproducibility, Openness, and LensKit</a>. In <cite
    class="pub-venue">Proceedings
    of the Fifth ACM Conference on Recommender Systems</cite> (RecSys ’11). ACM,
    New York, NY, USA, 133-140. DOI=<a
    href="http://dx.doi.org/10.1145/2043932.2043958">10.1145/2043932.2043958</a>.
    </div>

.. admonition:: BibTeX
    :class: hint dropdown

    .. code:: bibtex

        @inproceedings{LensKit,
            title = "Rethinking the Recommender Research Ecosystem: Reproducibility, Openness, and {LensKit}",
            booktitle = "Proceedings of the Fifth {ACM} Conference on Recommender Systems",
            author = "Ekstrand, Michael D and Ludwig, Michael and Konstan, Joseph A and Riedl, John T",
            publisher = "ACM",
            pages = "133--140",
            series = "RecSys '11",
            year =  2011,
            url = "http://doi.acm.org/10.1145/2043932.2043958",
            conference = "RecSys '11",
            doi = "10.1145/2043932.2043958"
        }


Known Papers
~~~~~~~~~~~~

.. raw:: html

    <script src="https://bibbase.org/show?bib=https%3A%2F%2Fapi.zotero.org%2Fusers%2F6655%2Fcollections%2F3TB3KT36%2Fitems%3Fkey%3DVFvZhZXIoHNBbzoLZ1IM2zgf%26format%3Dbibtex%26limit%3D100&jsonp=1"></script>
